<?php

/**
 * This file is part of the Nette Framework (http://nette.org)
 *
 * Copyright (c) 2004 David Grudl (http://davidgrudl.com)
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package Nette\Loaders
 */



/**
 * Nette auto loader is responsible for loading Nette classes and interfaces.
 *
 * @author     David Grudl
 * @package Nette\Loaders
 */
class NNetteLoader extends NAutoLoader
{
	/** @var NNetteLoader */
	private static $instance;

	/** @var array */
	public $list = array(
		'ArgumentOutOfRangeException' => '/Utils/exceptions',
		'DeprecatedException' => '/Utils/exceptions',
		'DirectoryNotFoundException' => '/Utils/exceptions',
		'FatalErrorException' => '/Utils/exceptions',
		'FileNotFoundException' => '/Utils/exceptions',
		'IAnnotation' => '/Reflection/IAnnotation',
		'IAuthenticator' => '/Security/IAuthenticator',
		'IAuthorizator' => '/Security/IAuthorizator',
		'ICacheStorage' => '/Caching/ICacheStorage',
		'ICollection' => '/Collections/ICollection',
		'IComponent' => '/ComponentModel/IComponent',
		'IComponentContainer' => '/ComponentModel/IComponentContainer',
		'IConfigAdapter' => '/Config/IConfigAdapter',
		'IDebuggable' => '/Debug/IDebuggable',
		'IFileTemplate' => '/Templates/IFileTemplate',
		'IFormControl' => '/Forms/IFormControl',
		'IFormRenderer' => '/Forms/IFormRenderer',
		'IHttpRequest' => '/Web/IHttpRequest',
		'IHttpResponse' => '/Web/IHttpResponse',
		'IIdentity' => '/Security/IIdentity',
		'IList' => '/Collections/IList',
		'IMailer' => '/Mail/IMailer',
		'IMap' => '/Collections/IMap',
		'INamingContainer' => '/Forms/INamingContainer',
		'IOException' => '/Utils/exceptions',
		'IPartiallyRenderable' => '/Application/IRenderable',
		'IPermissionAssertion' => '/Security/IPermissionAssertion',
		'IPresenter' => '/Application/IPresenter',
		'IPresenterLoader' => '/Application/IPresenterLoader',
		'IPresenterResponse' => '/Application/IPresenterResponse',
		'IRenderable' => '/Application/IRenderable',
		'IResource' => '/Security/IResource',
		'IRole' => '/Security/IRole',
		'IRouter' => '/Application/IRouter',
		'IServiceLocator' => '/Environment/IServiceLocator',
		'ISet' => '/Collections/ISet',
		'ISignalReceiver' => '/Application/ISignalReceiver',
		'IStatePersistent' => '/Application/IStatePersistent',
		'ISubmitterControl' => '/Forms/ISubmitterControl',
		'ITemplate' => '/Templates/ITemplate',
		'ITranslator' => '/Utils/ITranslator',
		'IUser' => '/Web/IUser',
		'InvalidStateException' => '/Utils/exceptions',
		'MemberAccessException' => '/Utils/exceptions',
		'NAbortException' => '/Application/Exceptions/AbortException',
		'NAmbiguousServiceException' => '/Environment/ServiceLocator',
		'NAnnotation' => '/Reflection/Annotation',
		'NAnnotations' => '/Reflection/Annotations',
		'NAnnotationsParser' => '/Reflection/AnnotationsParser',
		'NAppForm' => '/Application/AppForm',
		'NApplication' => '/Application/Application',
		'NApplicationException' => '/Application/Exceptions/ApplicationException',
		'NArrayList' => '/Collections/ArrayList',
		'NArrayTools' => '/Utils/ArrayTools',
		'NAuthenticationException' => '/Security/AuthenticationException',
		'NAutoLoader' => '/Loaders/AutoLoader',
		'NBadRequestException' => '/Application/Exceptions/BadRequestException',
		'NBadSignalException' => '/Application/Exceptions/BadSignalException',
		'NBaseTemplate' => '/Templates/BaseTemplate',
		'NButton' => '/Forms/Controls/Button',
		'NCFix' => '/loader',
		'NCache' => '/Caching/Cache',
		'NCachingHelper' => '/Templates/Filters/CachingHelper',
		'NCallback' => '/Utils/Callback',
		'NCheckbox' => '/Forms/Controls/Checkbox',
		'NClassReflection' => '/Reflection/ClassReflection',
		'NCliRouter' => '/Application/Routers/CliRouter',
		'NCollection' => '/Collections/Collection',
		'NComponent' => '/ComponentModel/Component',
		'NComponentContainer' => '/ComponentModel/ComponentContainer',
		'NConfig' => '/Config/Config',
		'NConfigAdapterIni' => '/Config/ConfigAdapterIni',
		'NConfigurator' => '/Environment/Configurator',
		'NControl' => '/Application/Control',
		'NConventionalRenderer' => '/Forms/Renderers/ConventionalRenderer',
		'NCurlyBracketsFilter' => '/Templates/Filters/LatteFilter',
		'NCurlyBracketsMacros' => '/Templates/Filters/LatteFilter',
		'NDateTime53' => '/Utils/DateTime',
		'NDebug' => '/Debug/Debug',
		'NDownloadResponse' => '/Application/Responses/DownloadResponse',
		'NDummyStorage' => '/Caching/DummyStorage',
		'NEnvironment' => '/Environment/Environment',
		'NExtensionReflection' => '/Reflection/ExtensionReflection',
		'NFileStorage' => '/Caching/FileStorage',
		'NFileUpload' => '/Forms/Controls/FileUpload',
		'NForbiddenRequestException' => '/Application/Exceptions/ForbiddenRequestException',
		'NForm' => '/Forms/Form',
		'NFormContainer' => '/Forms/FormContainer',
		'NFormControl' => '/Forms/Controls/FormControl',
		'NFormGroup' => '/Forms/FormGroup',
		'NForwardingResponse' => '/Application/Responses/ForwardingResponse',
		'NFramework' => '/Utils/Framework',
		'NFreezableObject' => '/Utils/FreezableObject',
		'NFtp' => '/Web/Ftp',
		'NFtpException' => '/Web/Ftp',
		'NFunctionReflection' => '/Reflection/FunctionReflection',
		'NGenericRecursiveIterator' => '/Utils/Iterators/GenericRecursiveIterator',
		'NHashtable' => '/Collections/Hashtable',
		'NHiddenField' => '/Forms/Controls/HiddenField',
		'NHtml' => '/Web/Html',
		'NHttpContext' => '/Web/HttpContext',
		'NHttpRequest' => '/Web/HttpRequest',
		'NHttpResponse' => '/Web/HttpResponse',
		'NHttpUploadedFile' => '/Web/HttpUploadedFile',
		'NIdentity' => '/Security/Identity',
		'NImage' => '/Utils/Image',
		'NImageButton' => '/Forms/Controls/ImageButton',
		'NImageMagick' => '/Utils/ImageMagick',
		'NInstanceFilterIterator' => '/Utils/Iterators/InstanceFilterIterator',
		'NInstantClientScript' => '/Forms/Renderers/InstantClientScript',
		'NInvalidLinkException' => '/Application/Exceptions/InvalidLinkException',
		'NInvalidPresenterException' => '/Application/Exceptions/InvalidPresenterException',
		'NJsonResponse' => '/Application/Responses/JsonResponse',
		'NKeyNotFoundException' => '/Collections/Hashtable',
		'NLatteFilter' => '/Templates/Filters/LatteFilter',
		'NLatteMacros' => '/Templates/Filters/LatteMacros',
		'NLimitedScope' => '/Loaders/LimitedScope',
		'NLink' => '/Application/Link',
		'NMail' => '/Mail/Mail',
		'NMailMimePart' => '/Mail/MailMimePart',
		'NMemcachedStorage' => '/Caching/MemcachedStorage',
		'NMethodReflection' => '/Reflection/MethodReflection',
		'NMultiRouter' => '/Application/Routers/MultiRouter',
		'NMultiSelectBox' => '/Forms/Controls/MultiSelectBox',
		'NNetteLoader' => '/Loaders/NetteLoader',
		'NObject' => '/Utils/Object',
		'NObjectMixin' => '/Utils/ObjectMixin',
		'NPaginator' => '/Utils/Paginator',
		'NParameterReflection' => '/Reflection/ParameterReflection',
		'NPermission' => '/Security/Permission',
		'NPresenter' => '/Application/Presenter',
		'NPresenterComponent' => '/Application/PresenterComponent',
		'NPresenterComponentReflection' => '/Application/PresenterComponentReflection',
		'NPresenterLoader' => '/Application/PresenterLoader',
		'NPresenterRequest' => '/Application/PresenterRequest',
		'NPropertyReflection' => '/Reflection/PropertyReflection',
		'NRadioList' => '/Forms/Controls/RadioList',
		'NRecursiveComponentIterator' => '/ComponentModel/ComponentContainer',
		'NRedirectingResponse' => '/Application/Responses/RedirectingResponse',
		'NRenderResponse' => '/Application/Responses/RenderResponse',
		'NRobotLoader' => '/Loaders/RobotLoader',
		'NRoute' => '/Application/Routers/Route',
		'NRule' => '/Forms/Rule',
		'NRules' => '/Forms/Rules',
		'NSafeStream' => '/Utils/SafeStream',
		'NSelectBox' => '/Forms/Controls/SelectBox',
		'NSendmailMailer' => '/Mail/SendmailMailer',
		'NServiceLocator' => '/Environment/ServiceLocator',
		'NSession' => '/Web/Session',
		'NSessionNamespace' => '/Web/SessionNamespace',
		'NSet' => '/Collections/Set',
		'NSimpleAuthenticator' => '/Security/SimpleAuthenticator',
		'NSimpleRouter' => '/Application/Routers/SimpleRouter',
		'NSmartCachingIterator' => '/Utils/Iterators/SmartCachingIterator',
		'NSnippetHelper' => '/Templates/Filters/SnippetHelper',
		'NString' => '/Utils/String',
		'NSubmitButton' => '/Forms/Controls/SubmitButton',
		'NTemplate' => '/Templates/Template',
		'NTemplateCacheStorage' => '/Templates/TemplateCacheStorage',
		'NTemplateFilters' => '/Templates/Filters/TemplateFilters',
		'NTemplateHelpers' => '/Templates/Filters/TemplateHelpers',
		'NTextArea' => '/Forms/Controls/TextArea',
		'NTextBase' => '/Forms/Controls/TextBase',
		'NTextInput' => '/Forms/Controls/TextInput',
		'NTools' => '/Utils/Tools',
		'NUri' => '/Web/Uri',
		'NUriScript' => '/Web/UriScript',
		'NUser' => '/Web/User',
		'NotImplementedException' => '/Utils/exceptions',
		'NotSupportedException' => '/Utils/exceptions',
	);



	/**
	 * Returns singleton instance with lazy instantiation.
	 * @return NNetteLoader
	 */
	public static function getInstance()
	{
		if (self::$instance === NULL) {
			self::$instance = new self;
		}
		return self::$instance;
	}



	/**
	 * Handles autoloading of classes or interfaces.
	 * @param  string
	 * @return void
	 */
	public function tryLoad($type)
	{
		$type = ltrim($type, '\\');
		if (isset($this->list[$type])) {
			NLimitedScope::load(NETTE_DIR . $this->list[$type] . '.php', TRUE);
			self::$count++;

		} elseif (substr($type, 0, 6) === 'Nette\\' && is_file($file = NETTE_DIR . strtr(substr($type, 5), '\\', '/') . '.php')) {
			NLimitedScope::load($file, TRUE);
			self::$count++;
		}
	}

}
