<?php

/**
 * Test: NLatteFilter::formatArray()
 *
 * @author     David Grudl
 * @package    Nette\Templates
 * @subpackage UnitTests
 */



require dirname(__FILE__) . '/../bootstrap.php';



// symbols

Assert::same( '',  NLatteFilter::formatArray('') );
Assert::same( '',  NLatteFilter::formatArray('', '&') );
Assert::same( 'array(1)',  NLatteFilter::formatArray('1') );
Assert::same( '&array(1)',  NLatteFilter::formatArray('1', '&') );
Assert::same( "array('symbol')",  NLatteFilter::formatArray('symbol') );
Assert::same( "array(1, 2,'symbol1','symbol2')",  NLatteFilter::formatArray('1, 2, symbol1, symbol2') );

// strings

Assert::same( 'array("\"1, 2, symbol1, symbol2")',  NLatteFilter::formatArray('"\"1, 2, symbol1, symbol2"') ); // unable to parse "${'"'}" yet
Assert::same( "array('\\'1, 2, symbol1, symbol2')",  NLatteFilter::formatArray("'\\'1, 2, symbol1, symbol2'") );
Assert::same( "array('\\\\'1, 2,'symbol1', symbol2')",  NLatteFilter::formatArray("'\\\\'1, 2, symbol1, symbol2'") );

// key words

Assert::same( 'array(TRUE, false, null, 1 or 1 and 2 xor 3, clone $obj, new Class)',  NLatteFilter::formatArray('TRUE, false, null, 1 or 1 and 2 xor 3, clone $obj, new Class') );
Assert::same( 'array(func (10))',  NLatteFilter::formatArray('func (10)') );

// associative arrays

Assert::same( "array('symbol1' =>'value','symbol2'=>'value')",  NLatteFilter::formatArray('symbol1 => value,symbol2=>value') );
Assert::same( "array('symbol1' => array ('symbol2' =>'value'))",  NLatteFilter::formatArray('symbol1 => array (symbol2 => value)') );
