<?php



/**
 * Routing debugger for Nette Framework.
 *
 * This file is part of the Nette Framework.
 * Copyright (c) 2004 David Grudl (http://davidgrudl.com)
 *
 * @author     David Grudl
 */
class RoutingDebugger extends NObject
{
	/** @var IRouter */
	private $router;

	/** @var IHttpRequest */
	private $httpRequest;

	/** @var NTemplate */
	private $template;



	/**
	 * Enables routing debugger.
	 * @return void
	 */
	public static function enable()
	{
		if (!NEnvironment::isProduction() && !NEnvironment::getHttpRequest()->isAjax()) {
			$debugger = new self(NEnvironment::getApplication()->getRouter(), NEnvironment::getHttpRequest());
			register_shutdown_function(array($debugger, 'paint'));
		}
	}



	public function __construct(IRouter $router, IHttpRequest $httpRequest)
	{
		$this->router = $router;
		$this->httpRequest = $httpRequest;
	}



	/**
	 * Renders debuger output.
	 * @return void
	 */
	public function paint()
	{
		if (strncmp(NEnvironment::getHttpResponse()->getHeader('Content-Type', 'text/html'), 'text/html', 9)) {
			return;
		}

		$this->template = new NTemplate;
		$this->template->setFile(dirname(__FILE__) . '/RoutingDebugger.phtml');
		$this->template->routers = new ArrayObject;
		$this->analyse($this->router);
		$this->template->render();
	}



	/**
	 * Analyses simple route.
	 * @param  IRouter
	 * @return void
	 */
	private function analyse($router)
	{
		if ($router instanceof NMultiRouter) {
			foreach ($router as $subRouter) {
				$this->analyse($subRouter);
			}
			return;
		}

		$appRequest = $router->match($this->httpRequest);
		$matched = $appRequest === NULL ? 'no' : 'may';
		if ($appRequest !== NULL && !isset($this->template->request)) {
			$this->template->request = $appRequest;
			$matched = 'yes';
		}

		$this->template->routers[] = array(
			'matched' => $matched,
			'class' => get_class($router),
			'defaults' => $router instanceof NRoute || $router instanceof NSimpleRouter ? $router->getDefaults() : array(),
			'mask' => $router instanceof NRoute ? $router->getMask() : NULL,
			'request' => $appRequest,
		);
	}

}
